/********************************************************/
/* SAS Programming Workshop - Plotting Data in SAS */
/* Presented by the Applied Statistics Lab - asl@uky.edu*/
/* Ya Qi - ya.qi@uky.edu*/
/********************************************************/

/* Import the data */ 
proc import out = practicedata file = 'S:\ASL Admin\Kristen\Programming Workshops\Plotting in SAS\Spring 2018\practicedata.xlsx' dbms=xlsx replace; 
	getnames = yes; 
	sheet="practicedata";
run; 

/* Look at the data */ 
proc contents data = practicedata; 
run;

/* Plotting One Quantitative Variable */

 
/* Creating a histogram */
proc sgplot data = practicedata;
	title 'Histogram of Response Variable'; /* change the main title */
	histogram respvar /
		 scale = count /* histogram of counts */
		 fillattrs = (color = red) /* change the color */;
	xaxis label = 'Response Variable'; /* change the x- axis label */
run;

proc univariate data = practicedata;
	title 'Histogram of Response Variable';
	histogram respvar;
run; 

/* Creating a boxplot */
proc sgplot data = practicedata;
	title 'Boxplot of Response Variable';
	xaxis label = 'Response Variable'; /* change the y axis label */
	vbox respvar //* use hbox instead if want horizontal boxplot*/
		 fillattrs = (color = red) /* change the color */;
run; 

/* Plotting One Categorical Variable */

/* Bar Chart */
proc sgplot data = practicedata;
	title 'Bar Chart of Groups';
	vbar groupvar; /* use hbar for horizontal barplots instead of vertical */
run;

/* Pie Chart */

proc gchart data = practicedata;
	title ' Pie Chart of Grouping Variable';
	pie groupvar;
run;
quit;


/* Plotting Two Variables */

/* Plotting One Quantitative and One Categorical Variable */
/* Side-by-side boxplots */

proc sgplot data = practicedata;
	title 'Boxplots';
	vbox respvar / group = groupvar;
	yaxis label = 'Response Variable';
run;

/* OR */

proc sort data = practicedata;
	by groupvar;
run; 
proc boxplot data = practicedata;
	plot respvar*groupvar; /* continuous variable*categorical variable */
	label respvar = 'Response Variable';
run; 

/* Two Histograms */

/* First, we need to sort by the grouping variable */
proc sort data = practicedata; 
	by groupvar;
run; 
proc sgplot data = practicedata;
	title 'Histogram of Response Variable';
	by groupvar; /* grouping variable used to break into two histograms */
	histogram respvar;
run;

/* Plotting two quantitative variables using a scatterplot */
proc sgplot data = practicedata;
	title 'Plot of Response Variable vs. Toy Variable';
	scatter x = toyvar y = respvar /
		markerattrs = (color = blue symbol = circlefilled); /* changes color and symbol */
	xaxis label = 'Toy Variable' display = (noticks novalues);
	yaxis label = 'Response Variable';
run;


/* Plots Showing More than Two Variables */

/* Create scatterplot with all data */
proc sgplot data = practicedata;
	title 'Plot of Response Variable vs. Toy Variable';
	scatter x = toyvar y = respvar /
		group = groupvar
		markerattrs = (symbol = circlefilled); /* changes symbol */
	xaxis label = 'Toy Variable' display = (noticks novalues);
	yaxis label = 'Response Variable';
	/* keylegend / noborder position = top title = 'Group Variable' location = inside; /* options to change the legend */
run;

/* Using sgpanel */
proc sgpanel data = practicedata;
	title 'Scatterplots of Response Variable against Toy Variable by Group';
	panelby groupvar; /* Variable you want to separate by */
	scatter x = toyvar y = respvar /
		markerattrs = (symbol = circlefilled);
	rowaxis label = 'Response Variable';
	colaxis label = 'Toy Variable' display = (noticks novalues);
run;


/**********************************************************************************************/
/*If you are in need of statistical assistance feel free to contact the ASL! To do so you can,*/
/* Submit a request: https://stat.as.uky.edu/asl*/
/*Email: asl@uky.edu*/
/**********************************************************************************************/




