/********************************************************/
/* SAS Programming Workshop - Plotting Data in SAS */
/* Presented by the Applied Statistics Lab - asl@uky.edu*/
/* Ya Qi - ya.qi@uky.edu*/
/********************************************************/

/* Import the data */ 
proc import out =  file = '' dbms= replace; 
	getnames = ; 
	sheet="";
run; 

/* Look at the data */ 
proc contents data = ; 
run;

/* Plotting One Quantitative Variable */

 
/* Creating a histogram */
proc sgplot data = ;
	title ''; /* change the main title */
	histogram  / scale =  /* histogram of counts */ fillattrs = (color = red) /* change the color */;
	xaxis label = ''; /* change the x- axis label */
run;

proc univariate data = ;
	title '';
	histogram ;
run; 

/* Creating a boxplot */
proc sgplot data = ;
	title '';
	xaxis label = ''; /* change the y axis label */
	vbox  //* use hbox instead if want horizontal boxplot*/	 fillattrs = (color = red) /* change the color */;
run; 

/* Plotting One Categorical Variable */

/* Bar Chart */
proc sgplot data = ;
	title '';
	vbar ; /* use hbar for horizontal barplots instead of vertical */
run;

/* Pie Chart */

proc gchart data = ;
	title '';
	pie ;
run;
quit;


/* Plotting Two Variables */

/* Plotting One Quantitative and One Categorical Variable */
/* Side-by-side boxplots */

proc sgplot data = ;
	title '';
	vbox  / group = ;
	yaxis label = '';
run;

/* OR */

proc sort data = ;
	by ;
run; 
proc boxplot data = ;
	plot ; /* continuous variable*categorical variable */
	label  = '';
run; 

/* Two Histograms */

/* First, we need to sort by the grouping variable */
proc sort data = ; 
	by ;
run; 
proc sgplot data = ;
	title '';
	by ; /* grouping variable used to break into two histograms */
	histogram ;
run;

/* Plotting two quantitative variables using a scatterplot */
proc sgplot data = ;
	title '';
	scatter x =  y =  / markerattrs = (color = blue symbol = circlefilled); /* changes color and symbol */
	xaxis label = '' display = (noticks novalues);
	yaxis label = '';
run;


/* Plots Showing More than Two Variables */

/* Create scatterplot with all data */
proc sgplot data = ;
	title '';
	scatter x =  y =  / group = markerattrs = (symbol = circlefilled); /* changes symbol */
	xaxis label = '' display = (noticks novalues);
	yaxis label = '';
	/* keylegend / noborder position = top title = 'Group Variable' location = inside; /* options to change the legend */
run;

/* Using sgpanel */
proc sgpanel data = ;
	title '';
	panelby ; /* Variable you want to separate by */
	scatter x =  y =  / markerattrs = (symbol = circlefilled);
	rowaxis label = '';
	colaxis label = '' display = (noticks novalues);
run;


/**********************************************************************************************/
/*If you are in need of statistical assistance feel free to contact the ASL! To do so you can,*/
/* Submit a request: https://stat.as.uky.edu/asl*/
/*Email: asl@uky.edu*/
/**********************************************************************************************/




